DRIVER_CONFIG = {
    'google': {
        'access_token_url': 'https://www.googleapis.com/oauth2/v4/token',
        'authorization_url': 'https://accounts.google.com/o/oauth2/v2/auth',
        'profile_url': 'https://www.googleapis.com/oauth2/v2/userinfo'
    },
    'github': {
        'access_token_url': 'https://github.com/login/oauth/access_token',
        'authorization_url': 'http://github.com/login/oauth/authorize',
        'profile_url': 'https://api.github.com/user'
    }
}
